djmessenger.management.commands package — djmessenger 1.1.0 documentation

# djmessenger.management.commands package

## Submodules

## djmessenger.management.commands.configure_get_started_button module

After configuring `djmessenger.settings.DJM_THREAD_SETTINGS_URL` and `djmessenger.settings.DJM_THREAD_ENABLE_GET_STARTED_BUTTON`, call this management command to actually configure get started button

class `djmessenger.management.commands.configure_get_started_button.` `Command`(stdout=None, stderr=None, no_color=False)

  Bases: `django.core.management.base.BaseCommand`

  `handle`(*args, **options)

## djmessenger.management.commands.configure_greetings module

After configuring `djmessenger.settings.DJM_THREAD_SETTINGS_URL` and `djmessenger.settings.DJM_THREAD_GREETINGS_TEXT`, call this management command to actually configure Greetings

class `djmessenger.management.commands.configure_greetings.` `Command`(stdout=None, stderr=None, no_color=False)

  Bases: `django.core.management.base.BaseCommand`

  `handle`(*args, **options)

## djmessenger.management.commands.configure_persistent_menu module

After configuring `djmessenger.settings.DJM_THREAD_PERSISTENT_MENUS`, call this management command to actually configure the persistent menu

class `djmessenger.management.commands.configure_persistent_menu.` `Command`(stdout=None, stderr=None, no_color=False)

  Bases: `django.core.management.base.BaseCommand`

  `handle`(*args, **options)

## djmessenger.management.commands.get_random_endpoint module

This management command is to provide a convenient way to get a random string act as the REST endpoint.

You just need to invoke this management command and then copy/paste the string provided to `djmessenger.settings.DJM_ENDPOINT`

class `djmessenger.management.commands.get_random_endpoint.` `Command`(stdout=None, stderr=None, no_color=False)

  Bases: `django.core.management.base.BaseCommand`

  `handle`(*args, **options)

## Module contents